--- PROJET BAGADI ---
--- IUT VANNES - DUT INFORMATIQUE ---

--- Version 0.5 ---

--- 17/01/08 creation v 0.1 ---
--- 21/01/08 modification des contraintes v0.2 ---
--- 27/02/08 modification tables + trigger v0.3 ---
--- 12/03/08 modification cl trangres + trigger v0.4 ---
--- 27/03/08 suppression des gotIt v0.5 ---



-- Delete --

DROP TABLE DiplomeStage;
DROP TABLE Stage;
DROP TABLE Contact;
DROP TABLE EntTypeServ;
DROP TABLE TypeServiceInfo;
DROP TABLE Fonction;
DROP TABLE AncienDiplome;
DROP TABLE DiplomeDansIUT;
DROP TABLE EffectueAutresEtudes;
DROP TABLE AutresEtudes;
DROP TABLE Ancien;
DROP TABLE ParcoursPro;
DROP TABLE Entreprise;



-- Tables --

-- Table Entreprise --

CREATE TABLE Entreprise (
        idEntreprise INTEGER CONSTRAINT pk_entreprise PRIMARY KEY NOT NULL,
        nom TEXT CONSTRAINT nn_nom NOT NULL,
        rue TEXT,
        codePostal INTEGER,
        ville TEXT CONSTRAINT nn_ville NOT NULL,
        pays TEXT CONSTRAINT nn_pays NOT NULL,
        telephone INTEGER,
        mail TEXT,
        url TEXT,
        formeJuridique TEXT,
        annee INTEGER,
        secteurActivite TEXT,
        nbSalaries INTEGER,
        tailleServiceInfo INTEGER,
	evaluation TEXT
);

-- Table Ancien --

CREATE TABLE Ancien (
        login TEXT CONSTRAINT pk_Ancien PRIMARY KEY,
        promo INTEGER CONSTRAINT nn_promo NOT NULL,
        nom TEXT CONSTRAINT nn_nom NOT NULL,
        prenom TEXT CONSTRAINT nn_prenom NOT NULL,
        nomMarital TEXT,
        dateNaissance TEXT CONSTRAINT nn_dateNaissance NOT NULL,
        sexe TEXT CONSTRAINT nn_sexe NOT NULL,
        telephoneFixe INTEGER,
        telephoneBureau INTEGER,
        telephonePortable INTEGER,
        mailPerso TEXT,
        mailPro TEXT,
        urlPerso TEXT,
        onListe INTEGER,
	onSite INTEGER,
	proposeStage INTEGER,
        urlCV TEXT,
        notesObservtions TEXT,
        codePostalPerso INTEGER,
        ruePerso TEXT,
        villePerso TEXT,
        paysPerso TEXT,
        codePostalFamille INTEGER,
        rueFamille TEXT,
        villeFamille TEXT,
        paysFamille TEXT,
        bacType TEXT,
        bacAnnee INTEGER
);

-- Table Fonction --

CREATE TABLE Fonction (
        idFonction INTEGER CONSTRAINT pk_Fonction PRIMARY KEY NOT NULL,
        specialite TEXT,
        metier TEXT
);

-- Table ParcoursPro --

CREATE TABLE ParcoursPro (
        idParcoursPro INTEGER CONSTRAINT pk_parcoursPro PRIMARY KEY NOT NULL,
        service TEXT,
        typeContrat TEXT,
        nbPersonneResponsable INTEGER,
        annee INTEGER,
        duree TEXT,
        actuellement INTEGER CONSTRAINT nn_actuellement NOT NULL,
        comp1 TEXT,
        comp2 TEXT,
        comp3 TEXT,
        entreprise INTEGER,
	ancienpp TEXT,
	fonction INTEGER
);

-- Table AutresEtudes --

CREATE TABLE AutresEtudes (
        idEtudes INTEGER CONSTRAINT pk_AutresEtudes PRIMARY KEY NOT NULL,
        diplome TEXT,
        annee INTEGER,
        pays TEXT,
        ville TEXT,
        universite TEXT,
        ecole TEXT
        );

-- Table EffectueAutresEtudes --

CREATE TABLE EffectueAutresEtudes (
        ancienae TEXT NOT NULL,
        etudes INTEGER NOT NULL,
        CONSTRAINT pk_EffectueAutresEtudes PRIMARY KEY (ancienae, etudes)
        );

-- Table DiplomeDansIUT --

CREATE TABLE DiplomeDansIUT(
        idDiplomeDansIUT INTEGER CONSTRAINT pk_idDiplomeDansIUT PRIMARY KEY NOT NULL,
        nom TEXT
);

-- Table AncienDiplome --

CREATE TABLE AncienDiplome (
        ancienad TEXT NOT NULL,
        diplome INTEGER NOT NULL,
        CONSTRAINT pk_AncienDiplome PRIMARY KEY (ancienad, diplome)
);
        

-- Table TypeServiceInfo --

CREATE TABLE TypeServiceInfo (
        idtypeServiceInfo INTEGER CONSTRAINT pk_TypeServiceInfo PRIMARY KEY NOT NULL,
        nom TEXT
);

-- Table EntTypeServ --

CREATE TABLE EntTypeServ (
        entreprise INTEGER NOT NULL,
        typeent INTEGER NOT NULL,
        CONSTRAINT pk_EntTypeServ PRIMARY KEY (entreprise, typeent)
        );

-- Table Contact --

CREATE TABLE Contact (
        idContact INTEGER CONSTRAINT pk_Contact PRIMARY KEY NOT NULL,
        nom TEXT,
        prenom TEXT,
        mail TEXT,
        rue TEXT,
        codePostal INTEGER,
        ville TEXT,
	telephone TEXT,
        entreprise INTEGER
);

-- Table Stage --

CREATE TABLE Stage (
        idStage INTEGER CONSTRAINT pk_Stage PRIMARY KEY NOT NULL,
        stageEffectue INTEGER,
	stagePropose INTEGER,
        annee INTEGER,
        entreprise INTEGER
);

-- Table DiplomeStage --

CREATE TABLE DiplomeStage (
        stage TEXT NOT NULL,
        diplome INTEGER NOT NULL,
        CONSTRAINT pk_DiplomeStage PRIMARY KEY (stage, diplome)
);

-- Triggers --

-- Foreign Key Preventing insert
CREATE TRIGGER fki_ParcoursPro_entreprise_Entreprise_idEntreprise
BEFORE INSERT ON [ParcoursPro]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "ParcoursPro" violates foreign key constraint "fki_ParcoursPro_entreprise_Entreprise_idEntreprise"')
  WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_ParcoursPro_entreprise_Entreprise_idEntreprise
BEFORE UPDATE ON [ParcoursPro]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "ParcoursPro" violates foreign key constraint "fku_ParcoursPro_entreprise_Entreprise_idEntreprise"')
      WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_ParcoursPro_entreprise_Entreprise_idEntreprise
BEFORE DELETE ON Entreprise
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Entreprise" violates foreign key constraint "fkd_ParcoursPro_entreprise_Entreprise_idEntreprise"')
  WHERE (SELECT entreprise FROM ParcoursPro WHERE entreprise = OLD.idEntreprise) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_ParcoursPro_ancienpp_Ancien_login
BEFORE INSERT ON [ParcoursPro]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "ParcoursPro" violates foreign key constraint "fki_ParcoursPro_ancienpp_Ancien_login"')
  WHERE NEW.ancienpp IS NOT NULL AND (SELECT login FROM Ancien WHERE login = NEW.ancienpp) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_ParcoursPro_ancienpp_Ancien_login
BEFORE UPDATE ON [ParcoursPro]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "ParcoursPro" violates foreign key constraint "fku_ParcoursPro_ancienpp_Ancien_login"')
      WHERE NEW.ancienpp IS NOT NULL AND (SELECT login FROM Ancien WHERE login = NEW.ancienpp) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_ParcoursPro_ancienpp_Ancien_login
BEFORE DELETE ON Ancien
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Ancien" violates foreign key constraint "fkd_ParcoursPro_ancienpp_Ancien_login"')
  WHERE (SELECT ancienpp FROM ParcoursPro WHERE ancienpp = OLD.login) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_ParcoursPro_fonction_Fonction_idFonction
BEFORE INSERT ON [ParcoursPro]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "ParcoursPro" violates foreign key constraint "fki_ParcoursPro_fonction_Fonction_idFonction"')
  WHERE NEW.fonction IS NOT NULL AND (SELECT idFonction FROM Fonction WHERE idFonction = NEW.fonction) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_ParcoursPro_fonction_Fonction_idFonction
BEFORE UPDATE ON [ParcoursPro]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "ParcoursPro" violates foreign key constraint "fku_ParcoursPro_fonction_Fonction_idFonction"')
      WHERE NEW.fonction IS NOT NULL AND (SELECT idFonction FROM Fonction WHERE idFonction = NEW.fonction) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_ParcoursPro_fonction_Fonction_idFonction
BEFORE DELETE ON Fonction
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Fonction" violates foreign key constraint "fkd_ParcoursPro_fonction_Fonction_idFonction"')
  WHERE (SELECT fonction FROM ParcoursPro WHERE fonction = OLD.idFonction) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_EffectueAutresEtudes_ancienae_Ancien_login
BEFORE INSERT ON [EffectueAutresEtudes]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "EffectueAutresEtudes" violates foreign key constraint "fki_EffectueAutresEtudes_ancienae_Ancien_login"')
  WHERE NEW.ancienae IS NOT NULL AND (SELECT login FROM Ancien WHERE login = NEW.ancienae) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_EffectueAutresEtudes_ancienae_Ancien_login
BEFORE UPDATE ON [EffectueAutresEtudes]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "EffectueAutresEtudes" violates foreign key constraint "fku_EffectueAutresEtudes_ancienae_Ancien_login"')
      WHERE NEW.ancienae IS NOT NULL AND (SELECT login FROM Ancien WHERE login = NEW.ancienae) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_EffectueAutresEtudes_ancienae_Ancien_login
BEFORE DELETE ON Ancien
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Ancien" violates foreign key constraint "fkd_EffectueAutresEtudes_ancienae_Ancien_login"')
  WHERE (SELECT ancienae FROM EffectueAutresEtudes WHERE ancienae = OLD.login) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_EffectueAutresEtudes_etudes_AutresEtudes_idEtudes
BEFORE INSERT ON [EffectueAutresEtudes]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "EffectueAutresEtudes" violates foreign key constraint "fki_EffectueAutresEtudes_etudes_AutresEtudes_idEtudes"')
  WHERE NEW.etudes IS NOT NULL AND (SELECT idEtudes FROM AutresEtudes WHERE idEtudes = NEW.etudes) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_EffectueAutresEtudes_etudes_AutresEtudes_idEtudes
BEFORE UPDATE ON [EffectueAutresEtudes]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "EffectueAutresEtudes" violates foreign key constraint "fku_EffectueAutresEtudes_etudes_AutresEtudes_idEtudes"')
      WHERE NEW.etudes IS NOT NULL AND (SELECT idEtudes FROM AutresEtudes WHERE idEtudes = NEW.etudes) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_EffectueAutresEtudes_etudes_AutresEtudes_idEtudes
BEFORE DELETE ON AutresEtudes
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "AutresEtudes" violates foreign key constraint "fkd_EffectueAutresEtudes_etudes_AutresEtudes_idEtudes"')
  WHERE (SELECT etudes FROM EffectueAutresEtudes WHERE etudes = OLD.idEtudes) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_AncienDiplome_ancienad_Ancien_login
BEFORE INSERT ON [AncienDiplome]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "AncienDiplome" violates foreign key constraint "fki_AncienDiplome_ancienad_Ancien_login"')
  WHERE NEW.ancienad IS NOT NULL AND (SELECT login FROM Ancien WHERE login = NEW.ancienad) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_AncienDiplome_ancienad_Ancien_login
BEFORE UPDATE ON [AncienDiplome]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "AncienDiplome" violates foreign key constraint "fku_AncienDiplome_ancienad_Ancien_login"')
      WHERE NEW.ancienad IS NOT NULL AND (SELECT login FROM Ancien WHERE login = NEW.ancienad) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_AncienDiplome_ancienad_Ancien_login
BEFORE DELETE ON Ancien
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Ancien" violates foreign key constraint "fkd_AncienDiplome_ancienad_Ancien_login"')
  WHERE (SELECT ancienad FROM AncienDiplome WHERE ancienad = OLD.login) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_AncienDiplome_diplome_DiplomeDansIUT_idDiplomeDansIUT
BEFORE INSERT ON [AncienDiplome]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "AncienDiplome" violates foreign key constraint "fki_AncienDiplome_diplome_DiplomeDansIUT_idDiplomeDansIUT"')
  WHERE NEW.diplome IS NOT NULL AND (SELECT idDiplomeDansIUT FROM DiplomeDansIUT WHERE idDiplomeDansIUT = NEW.diplome) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_AncienDiplome_diplome_DiplomeDansIUT_idDiplomeDansIUT
BEFORE UPDATE ON [AncienDiplome]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "AncienDiplome" violates foreign key constraint "fku_AncienDiplome_diplome_DiplomeDansIUT_idDiplomeDansIUT"')
      WHERE NEW.diplome IS NOT NULL AND (SELECT idDiplomeDansIUT FROM DiplomeDansIUT WHERE idDiplomeDansIUT = NEW.diplome) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_AncienDiplome_diplome_DiplomeDansIUT_idDiplomeDansIUT
BEFORE DELETE ON DiplomeDansIUT
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "DiplomeDansIUT" violates foreign key constraint "fkd_AncienDiplome_diplome_DiplomeDansIUT_idDiplomeDansIUT"')
  WHERE (SELECT diplome FROM AncienDiplome WHERE diplome = OLD.idDiplomeDansIUT) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_EntTypeServ_entreprise_Entreprise_idEntreprise
BEFORE INSERT ON [EntTypeServ]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "EntTypeServ" violates foreign key constraint "fki_EntTypeServ_entreprise_Entreprise_idEntreprise"')
  WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_EntTypeServ_entreprise_Entreprise_idEntreprise
BEFORE UPDATE ON [EntTypeServ]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "EntTypeServ" violates foreign key constraint "fku_EntTypeServ_entreprise_Entreprise_idEntreprise"')
      WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_EntTypeServ_entreprise_Entreprise_idEntreprise
BEFORE DELETE ON Entreprise
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Entreprise" violates foreign key constraint "fkd_EntTypeServ_entreprise_Entreprise_idEntreprise"')
  WHERE (SELECT entreprise FROM EntTypeServ WHERE entreprise = OLD.idEntreprise) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_EntTypeServ_typeent_TypeServiceInfo_idtypeServiceinfo
BEFORE INSERT ON [EntTypeServ]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "EntTypeServ" violates foreign key constraint "fki_EntTypeServ_typeent_TypeServiceInfo_idtypeServiceinfo"')
  WHERE NEW.typeent IS NOT NULL AND (SELECT idtypeServiceinfo FROM TypeServiceInfo WHERE idtypeServiceinfo = NEW.typeent) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_EntTypeServ_typeent_TypeServiceInfo_idtypeServiceinfo
BEFORE UPDATE ON [EntTypeServ]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "EntTypeServ" violates foreign key constraint "fku_EntTypeServ_typeent_TypeServiceInfo_idtypeServiceinfo"')
      WHERE NEW.typeent IS NOT NULL AND (SELECT idtypeServiceinfo FROM TypeServiceInfo WHERE idtypeServiceinfo = NEW.typeent) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_EntTypeServ_typeent_TypeServiceInfo_idtypeServiceinfo
BEFORE DELETE ON TypeServiceInfo
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "TypeServiceInfo" violates foreign key constraint "fkd_EntTypeServ_typeent_TypeServiceInfo_idtypeServiceinfo"')
  WHERE (SELECT typeent FROM EntTypeServ WHERE typeent = OLD.idtypeServiceinfo) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_Contact_entreprise_Entreprise_idEntreprise
BEFORE INSERT ON [Contact]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "Contact" violates foreign key constraint "fki_Contact_entreprise_Entreprise_idEntreprise"')
  WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_Contact_entreprise_Entreprise_idEntreprise
BEFORE UPDATE ON [Contact]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "Contact" violates foreign key constraint "fku_Contact_entreprise_Entreprise_idEntreprise"')
      WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_Contact_entreprise_Entreprise_idEntreprise
BEFORE DELETE ON Entreprise
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Entreprise" violates foreign key constraint "fkd_Contact_entreprise_Entreprise_idEntreprise"')
  WHERE (SELECT entreprise FROM Contact WHERE entreprise = OLD.idEntreprise) IS NOT NULL;
END;

-- Foreign Key Preventing insert
CREATE TRIGGER fki_Stage_entreprise_Entreprise_idEntreprise
BEFORE INSERT ON [Stage]
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'insert on table "Stage" violates foreign key constraint "fki_Stage_entreprise_Entreprise_idEntreprise"')
  WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing update
CREATE TRIGGER fku_Stage_entreprise_Entreprise_idEntreprise
BEFORE UPDATE ON [Stage]
FOR EACH ROW BEGIN
    SELECT RAISE(ROLLBACK, 'update on table "Stage" violates foreign key constraint "fku_Stage_entreprise_Entreprise_idEntreprise"')
      WHERE NEW.entreprise IS NOT NULL AND (SELECT idEntreprise FROM Entreprise WHERE idEntreprise = NEW.entreprise) IS NULL;
END;

-- Foreign key preventing delete
CREATE TRIGGER fkd_Stage_entreprise_Entreprise_idEntreprise
BEFORE DELETE ON Entreprise
FOR EACH ROW BEGIN
  SELECT RAISE(ROLLBACK, 'delete on table "Entreprise" violates foreign key constraint "fkd_Stage_entreprise_Entreprise_idEntreprise"')
  WHERE (SELECT entreprise FROM Stage WHERE entreprise = OLD.idEntreprise) IS NOT NULL;
END;