//
//	Librairie by The Rubik's Man
//		  2005-2006
//
/**
  *
  *	Classe AutoCompleteur
  *
  *		Syntaxe :
  *			new AutoCompleteur(
  *				id input source,
  *				id element cible || null, 												//( si null alors un element est cree automatiquement avec l'id : 'id input source'+'_updateContainer')
  *				url fichier traitement ajax || tableau de chaines de caracteres,					// ( si url alors mode Ajax et si tableau alors mode Local )
  *				{	
  *					Ajax: {
  *							method: String										// Methode de la requete Ajax  POST ou GET ( defaut a POST )
  *							paramName: String,									// defaut : soit l'attribut name de l'element source s'il existe ou alors 'autocompletion_param'
  *							asynchronous: Boolean									// mode asynchrone de la requete Ajax ( defaut a true )
  *						},
  *					Local: {
  *							searchOnlyAtBegin:Boolean,								// Recherche partout dans la chaine ou seulement a partir du debut ( defaut a true )
  *							nbrMinPartialChars: Number,								// Nombre de caracteres minimum si searchOnlyAtBegin est a true pour que la recherche partielle s'enclenche ( defaut a 2 )
  *							respectCase: Boolean									// Respect de la casse ( majuscule ou minuscule ) ( defaut a false )
  *						},
  *					Global: {
  *							nbrCharsStart: Number,									// Nombre de caracteres minimum pour activer l'autocompletion ( defaut a 1 )
  *							pingBlurTime: Number,									// Temps en seconde apres lequel le container de l'autocompletion doit se fermer apres une perte de focus ( defaut a 0.2 )
  *							pingOpenTime: Number,									// Temps en seconde apres lequel le container de l'autocompletion doit s'ouvrir apres un evenement d'ouverture ( defaut a 0.2 )
  *							nbrMaxItem: Number,									// Nombre d'items de l'autocompletion affiches ( defaut a 5 )
  *							classToIgnore: String									// Nom de la classe dans lequel sont affichs des informations a ignorer lors de la validation ( defaut classe 'description' )
  *						},
  *					Extra: {
  *							openEffect: String,									// Nom de l'effet d'ouverture ( voir documentation. defaut c'est l'effet ' fade ' )
  *							hideEffect: String,									// Nom de l'effet de fermeture ( voir documentation. defaut c'est l'effet ' fade ' )
  *							beforeDisplay: Function(element source,element cible), 				// Fonction executee juste avant l'envoi de la requete ou de la recherche ( defaut fonction vide )
  *							afterDisplay: Function(element source,element cible), 				// Fonction executee juste apres l'affichage ( defaut fonction vide )
  *							afterValidate: Function(element source,element cible,chaine recuperee), 	// Fonction executee lors de la validation
  *							signature: String										// Code HTML de signature insere a la fin de chaque liste ( code interieur a une balise <div>String</div> )
  *						}
  *				}
  *			);
  *			ex : new AutoCompleteur('input1','div1','ajax.php',{Global:{classToTignore:'informations'}, Ajax:{paramName:'my_param'},Extra:{openEffect:'blind',hideEffect:'puff'}});	
  *		
  *			Tous les parametres sont obligatoires sauf les options, et chaque parametre dans options est redefinissable mais peut etre laisse a son defaut
  *
  *
  *
  */
var AutoCompleteur = function() {
      this.initialize.apply(this, arguments);
}
AutoCompleteur.prototype = {
	/**
	  *	Constructeur de la classe AutoCompleteur
	  *		Instancie et initialise tous les elements et evenements
	  *
	  *		@ param element		=>	id de l'input source de l'autocompletion
	  *		@ param updateElement	=>	id de l'element cible de l'autocompletion || null	( si null alors l'element sera cree automatiquement )
	  *		@ param urlOrArray	=>	url du fichier de traitement pour Ajax || tableau de propositions pour le mode Local
	  *		@ options			=>	objet contenant les differentes options composs de 3 sous-objets : Ajax,Local,Global et Extra
	  */
	initialize: function (element, updateElement, urlOrArray, options) {
			if ( !AutoCompletion.librariesController() ) return;	// Verifie la presence des librairies
			this.rewriteFunctions();	// Redefinition des certaines methodes des librairies " Effects " et " Prototype "
			
			//  Recuperation ou creation de l'objet des options
			var options = options || {};
			options = {
				Ajax: options.Ajax || {},
				Local: options.Local || {},
				Global: options.Global || {},
				Extra: options.Extra || {}
			};
			
			// Elements importans : (element source,element cible,fichier ajax ou tableau local)
			this.element = $(element);
			this.updateElement = $(updateElement) || this.createUpdateContainer();
			this.urlAnsweringFile = typeof urlOrArray == 'string' ? urlOrArray : null;
			this.localArray = this.urlAnsweringFile == null ? urlOrArray : null; 
			this.autoCompletionMode = this.localArray == null ? 'Ajax' : 'Local';
			this.signature = options.Extra.signature || false;
			
			// Variables d'etat courant de l'autocompleteur
			this.state = {
				currentIndex: 0,
				totalIndex: 0,
				opened: false,
				timer: null
			};
			
			this.globalOptions = {
				// Proprietes pouvant etre redefinies
				nbrCharsStart: options.Global.nbrCharsStart || 1,
				pingBlurTime: options.Global.pingBlurTime || 0.2,
				pingOpenTime: options.Global.pingOpenTime || 0.2,
				nbrMaxItem: options.Global.nbrMaxItem || 5,
				classToIgnore: options.Global.classToIgnore || 'description'
			};
			
			
			this.AjaxModePackage =  {
				// Proprietes pouvant etre redefinies
				method: options.Ajax.method || 'post',
				paramName: options.Ajax.paramName || this.element.name || 'autocompletion_param',
				asynchronous: $D(options.Ajax.asynchronous) ? options.Ajax.asynchronous : true,
				
				// Proprietes privees
				parameters: '',
				onComplete: function (answer) {
					this.updateItems(answer.responseText);
				}.bind(this)
			};
			
			this.LocalModePackage = {
				// Proprietes pouvant etre redefinies
				searchOnlyAtBegin: $D(options.Local.searchOnlyAtBegin) ? options.Local.searchOnlyAtBegin : true,
				nbrMinPartialChars: options.Local.nbrMinPartialChars || 2,
				respectCase : $D(options.Local.respectCase) ? options.Local.respectCase : false,
				
				// Proprietes privees
				finder: this.extraFunctions.localStringFinder.bind(this)
			};
			
			// Fonctions que l'on peut redifinir
			this.onFunctions = {
				//  displayer	=>	methode qui affiche la liste d'autocompletion
				displayer:	this.Effects.displayers(options.Extra.openEffect) ||
							this.Effects.displayers.fade,
							
				//  hider		=>	methode qui cache la liste d'autocompletion
				hider: 	this.Effects.hiders(options.Extra.hideEffect) || 
						this.Effects.hiders.fade,
						
				//  beforeDisplay		=>	methode executee avant affichage
				beforeDisplay:	options.Extra.beforeDisplay || 
								Prototype.emptyFunction,
								
				//  afterDisplay		=>	methode executee apres affichage
				afterDisplay:	options.Extra.afterDisplay || 
								Prototype.emptyFunction,
								
				//  afterValidate 		=>	methode executee aprs validation ( click ou touche entree )
				afterValidate:	options.Extra.afterValidate ||
								function(element,updateElement,validatedElement,collectedText){
									if (validatedElement) element.value = collectedText;
								}
			};
			
			Element.hide(this.updateElement); // Masquage du container qui recevra la liste d'autocompletion
			// Si l'element n'a pas de position definie alors on lui assigne la position absolute
			if (!this.updateElement.style.position) {
				this.updateElement.style.position = 'absolute';
			}
			// Si le navigateur est IE alors on lance le FIX qui va regler le probleme des <select> qui sont toujours au premier plan
			if( (navigator.appVersion.indexOf('MSIE')>0) &&
				(navigator.userAgent.indexOf('Opera')<0) &&
				(this.updateElement.style.position == 'absolute')) {
					this.IEFixFrame = this.extraFunctions.IEFixFrameCreator.bind(this)();
			}
			// Puis finalement on instancie les observateurs de l'input source
			this.observeElement();
	},
	
	/**
	  *	Fonction permettant de creer ou de modifier quelques fonctions utiles
	  */
	rewriteFunctions: function () {
		Position.clone = this.extraFunctions.clone;
		$D = function (object) {
			return typeof object != 'undefined';
		}
		Element.recursiveClean = function (element) {
			if (element.hasChildNodes()) {
				Element.cleanWhitespace(element);
				$A(element.childNodes).each(Element.recursiveClean);
			}
			else Element.cleanWhitespace(element);
			return element;
		}
		Effect.Squish = this.extraFunctions.squishEffect;
	},
	
	/**
	  *	Fonction permettant d'ajouter les observeurs des evenements utiles de l'input source
	  */
	observeElement: function () {
		Event.observe(this.element, 'blur', this.eventFunctions.blur.bindAsEventListener(this));
		Event.observe(this.element, 'keydown', this.eventFunctions.keyPress.bindAsEventListener(this));
		Event.observe(this.element, 'mouseover', this.eventFunctions.mouseOver.bindAsEventListener(this));
	},
	
	/**
	  *	Fonction permettant d'ajouter les observeurs des evenements utiles pour un item de l'autocompletion
	  *
	  *		@ param item	=>	element de choix de l'autocompletion ici cela sera un element LI
	  */
	observeItem: function (item) {
		Event.observe(item, 'click', this.eventFunctions.click.bindAsEventListener(this));
		Event.observe(item, 'mouseover', this.eventFunctions.mouseOver.bindAsEventListener(this));
	},
	
	/**
	  *	Fonction permettant de creer un container target juste aprs l'input source si jamais aucun element cible n'a ete indique
	  */
	createUpdateContainer: function () {
		new Insertion.After(
			this.element,
			'<div id="'+this.element.id+'_updateContainer" class="'+this.element.id+'_updatedContainer"></div>'
		);
		return $(this.element.id+'_updateContainer');
	},
	
	/**
	  *	Definition de toutes les fonctions executees lors des differents evenements pouvant intervenir
	  */
	eventFunctions: {
		/**
		  *	Evenement click lors d'un click sur une proposition de l'autocompleteur
		  */
		click: function (e) {
			if (!this.state.opened) return;
			
			this.validate();
			Event.stop(e);
			Form.Element.focus(this.element);
		},
		
		/**
		  *	Evenement blur lors de la perte de focus de l'element source
		  */
		blur: function (e) {
			clearTimeout(this.state.timer);
			if (!this.state.opened) return;
			
			setTimeout(this.close.bind(this), this.globalOptions.pingBlurTime*1000);
			Event.stop(e);
		},
		
		/**
		  *	Evenement mouseOver lors d'un deplacement de la souris
		  */
		mouseOver: function (e) {
			if (!this.state.opened) return;
			
			this.state.currentIndex = Event.findElement(e, 'LI').ptrIndex || 0;
			this.updateClass();
			Event.stop(e);
		},
		
		/**
		  *	Evenement keyPress lors d'un evenement clavier
		  */
		keyPress: function (e) {
			// Si le container n'est pas ouvert lors de l'evenement
			if (!this.state.opened) { // On bloque laisse les touches suivantes agir comme d'origine
				if ( e.keyCode == Event.KEY_RETURN 	|| 
					 e.keyCode == Event.KEY_TAB 	||
					 e.keyCode == Event.KEY_LEFT 	||
					 e.keyCode == Event.KEY_RIGHT )
					return;
				
				// Si une touche activante a ete pressee alors on ouvre le container
				if (this.state.timer != null) clearTimeout(this.state.timer);
				this.state.timer = setTimeout(this.open.bind(this),this.globalOptions.pingOpenTime*1000);
				return;
			}
			// Si le container est ouvert lors de l'evenement
			// Touches interceptees
			switch (e.keyCode) {
				case Event.KEY_DOWN :			// Touche Bas
						this.toNextItem();
						this.updateClass();
						Event.stop(e);
						return;
				
				case Event.KEY_UP :				// Touche Haut
						this.toPrevItem();
						this.updateClass();
						Event.stop(e);
						return;
				
				case Event.KEY_RETURN :			// Touche Entree
						this.validate();
				
				case Event.KEY_ESC :			// Touche Echap et Entree
						this.close();
						Event.stop(e);
				case Event.KEY_TAB :			// Touche Tab, Echap et Entree
						return;
				
				case Event.KEY_PAGEUP :			// Touche Page Haut
						this.toFirstItem();
						this.updateClass();
						Event.stop(e);
						return;
				
				case Event.KEY_PAGEDOWN :		// Touche Page Bas
						this.toLastItem();
						this.updateClass();
						Event.stop(e);
						return;
						
				case Event.KEY_LEFT :			// Touche Gauche
				case Event.KEY_RIGHT :			// Touche Droite
						return;
			}
			
			// Si touche non interceptee => caractere
			if ( this.state.timer != null ) clearTimeout(this.state.timer);
			this.state.timer = setTimeout(this.getItems.bind(this),0);
			return true;
		}
	},
	
	/**
	  *	Fonction permettant de fermer le container avec l'effet defini
	  */
	close: function () {
		this.state.opened = false;
		if (this.updateElement.style.display != 'none') this.onFunctions.hider(this.element,this.updateElement);
		if (this.IEFixFrame) setTimeout(this.extraFunctions.IEFixFrameHider.bind(this),50);
	},
	
	/**
	  *	Fonction permettant d'ouvrir le container
	  */
	open: function () {
		this.state.opened = true;
		this.getItems();
	},
	
	/**
	  *	Fonction permettant d'afficher l'ouverture du container avec l'effet defini si jamais celui-ci n'est pas deja ouvert
	  */
	display: function () {
		this.onFunctions.afterDisplay(this.element, this.updateElement);
		
		var firstOpen = false;
		if (this.updateElement.style.display == 'none') {
			this.onFunctions.displayer(this.element, this.updateElement);
			firstOpen = true;
		}
		if (this.IEFixFrame) setTimeout(this.extraFunctions.IEFixFrameAdapter.bind(this),(
			this.onFunctions.displayer != this.Effects.displayers.fade ?
				(firstOpen ? 0.3 : 0.05)*1000 : 0.05*1000
			)
		);
	},
	
	/**
	  *	Fonction permettant de changer le pointeur de l'item selectionner au suivant
	  */
	toNextItem: function () {
		this.state.currentIndex = this.state.currentIndex == this.state.totalIndex ? 0 : this.state.currentIndex + 1;
	},
	
	/**
	  *	Fonction permettant de changer le pointeur de l'item selectionner au precedent
	  */
	toPrevItem: function () {
		this.state.currentIndex = this.state.currentIndex == 0 ? this.state.totalIndex : this.state.currentIndex - 1;
	},
	
	/**
	  *	Fonction permettant de changer le pointeur de l'item selectionner au dernier
	  */
	toLastItem: function () {
		this.state.currentIndex = this.state.totalIndex;
	},
	
	/**
	  *	Fonction permettant de changer le pointeur de l'item selectionner au premier
	  */
	toFirstItem: function () {
		this.state.currentIndex = 1;
	},
	
	/**
	  *	Fonction permettant de mettre a jour la classe focused sur les elements courants
	  */
	updateClass: function () {
		$$('#'+this.updateElement.id+' ul li').each(
			function (LIitem, i) {
				if (this.state.currentIndex == LIitem.ptrIndex) Element.addClassName(LIitem, 'focused');
				else Element.removeClassName(LIitem, 'focused');
			}.bind(this)
		);
	},
	
	/**
	  *	Fonction permettant de faire les traitements lors de la validation par un click ou la touche Entree
	  */
	validate: function () {
		var itemSelected = this.state.currentIndex == 0 ? false : true;
		var validatedElement = false;
		var collectedText = false;
		if(itemSelected) {
			validatedElement = $$('#'+this.updateElement.id+' ul li')[this.state.currentIndex-1];
			var collectedText = Element.collectTextNodesIgnoreClass(
				Element.recursiveClean(validatedElement),
				this.globalOptions.classToIgnore
			);
		}
		this.onFunctions.afterValidate.bind(this)(this.element,this.updateElement,validatedElement,collectedText);
	},
	
	/**
	  *	Fonction permettant de recuperer les choix d'une autocompletion suivant le mode Ajax ou Local
	  */
	getItems : function () {		
		if (this.element.value.length < this.globalOptions.nbrCharsStart) {
			this.close();
			return;
		}
		
		this.onFunctions.beforeDisplay(this.element, this.updateElement);
		
		if (this.autoCompletionMode == 'Ajax') {
			this.AjaxModePackage.parameters = this.AjaxModePackage.paramName+'='+this.element.value+'&limit='+this.globalOptions.nbrMaxItem;
			new Ajax.Request(this.urlAnsweringFile, this.AjaxModePackage);
		}
		else this.updateItems(this.LocalModePackage.finder(this.element.value));
	},
	
	/**
	  *	Fonction permettant de mettre a jour le code HTML du container cible de l'autocompletion
	  *
	  *		@ param string	=>	chaine de caractere contenant le code genere resultat de la requete ou de la recherche locale
	  */
	updateItems: function (string) {
		var tempElement = document.createElement('div');
		tempElement.innerHTML = string;
		if (tempElement.getElementsByTagName('LI').length == 0) {
			this.close();
			return;
		}
		this.updateElement.innerHTML = string;
		
		if (this.signature) {
			this.updateElement.innerHTML += '<div class="signature">'+this.signature+'</div>';
		}
		
		$$('#'+this.updateElement.id+' ul li').each(
			function (LIitem, i) {
				if (i < this.globalOptions.nbrMaxItem) {
					LIitem.ptrIndex = i + 1;
					this.observeItem(LIitem);
				}
				else Element.remove(LIitem);
			}.bind(this)
		);
		
		this.state.totalIndex = $$('#'+this.updateElement.id+' ul li').length;
		this.state.currentIndex = 0;
		
		this.display();
	},
	
	/**
	  *	Definition des fonctions permettant d'appliquer des effets d'affichage ou de masquage
	  *		2 sous-objets : displayers ( afficheurs )  et  hiders ( masqueur )
	  */
	Effects: {
		displayers: function (effect) {
			switch (effect) {
				default: 
					return function (element, updateElement) {
						Element.setOpacity(updateElement,0);
						Element.show(updateElement);
						Position.clone(element, updateElement, {
							setHeight: false,
							offsetTop: element.offsetHeight,
							toBorder: true
						});
						Effect.Appear(updateElement,{duration:0.4});
					}
				
				case 'noeffect':
					return function(element,updateElement) {
						Element.setOpacity(updateElement,0);
						Element.show(updateElement);
						Position.clone(element, updateElement, {
							setHeight: false, 
							offsetTop: element.offsetHeight,
							toBorder: true
						});
						Element.hide(updateElement);
						Element.setOpacity(updateElement,1);
						Element.show(updateElement);
					}
				
				
				case 'slide':
					return function (element,updateElement) {
						Element.setOpacity(updateElement,0);
						Element.show(updateElement);
						Position.clone(element, updateElement, {
							setHeight: false, 
							offsetTop: element.offsetHeight,
							toBorder: true
						});
						Element.hide(updateElement);
						Element.setOpacity(updateElement,1);
						Effect.SlideDown(updateElement,{duration:0.2});
					}
						
				case 'blind': 
					return function (element,updateElement) {
						Element.setOpacity(updateElement,0);
						Element.show(updateElement);
						Position.clone(element, updateElement, {
							setHeight: false,
							offsetTop: element.offsetHeight, 
							toBorder: true
						});
						Element.hide(updateElement);
						Element.setOpacity(updateElement,1);
						Effect.BlindDown(updateElement,{duration:0.2});
					}
					
				case 'grow':
					return function (element,updateElement) {
						Element.setOpacity(updateElement,0);
						Element.show(updateElement);
						Position.clone(element, updateElement, {
							setHeight: false, 
							offsetTop: element.offsetHeight, 
							toBorder: true
						});
						Element.hide(updateElement);
						Element.setOpacity(updateElement,1);
						Effect.Grow(updateElement,{duration:0.2});
					}
			}
		},
		hiders: function (effect) {
			switch(effect) {
				default: 
					return function (element, updateElement) {
						Effect.Fade(updateElement,{duration:0.4});
					}
				
				case 'noeffect':
					return function (element, updateElement) {
						Element.hide(updateElement);
					}
				
				case 'slide': 
					return function (element, updateElement) {
						Effect.SlideUp(updateElement,{duration:0.2});
					}
					
				case 'blind': 
					return function (element, updateElement) {
						Effect.BlindUp(updateElement,{duration:0.2});
					}
					
				case 'puff': 
					return function (element, updateElement) {
						Effect.Puff(updateElement,{duration:0.2});
					}
					
				case 'fold': 
					return function (element, updateElement) {
						Effect.Fold(updateElement,{duration:0.2});
					}
					
				case 'squish': 
					return function (element, updateElement) {
						Effect.Squish(updateElement,{duration:0.2});
					}
					
				case 'shrink': 
					return function (element, updateElement) {
						Effect.Shrink(updateElement,{duration:0.2});
					}
			}
		}
	},
	
	/**
	  *	Definition de fonctions supplementaires utiles
	  */
	extraFunctions: {
		/**
		  *	Fonction permettant de creer le BugFix pour IE en creant une IFRAME invisible
		  */
		IEFixFrameCreator: function () {
			new Insertion.After(
				this.updateElement,
				'<iframe id="'+this.updateElement.id+'_iefix" '+
				'style="display:none;position:absolute;filter:progid:DXImageTransform.Microsoft.Alpha(opacity=0);" '+
				'src="javascript:false;" frameborder="0" scrolling="no"></iframe>'
			);
			return $(this.updateElement.id+'_iefix');
		},
		/**
		  *	Fonction permettant d'adapter les dimensions et la position de l'IFRAME a celles du container dans l'etat courant
		  */
		IEFixFrameAdapter: function () {
			Position.clone(this.updateElement, this.IEFixFrame);
		    this.IEFixFrame.style.zIndex = 1;
		    this.updateElement.style.zIndex = 2;
		    Element.show(this.IEFixFrame);
		},
		/**
		  *	Fonction permettant de cacher l'IFRAME
		  */
		IEFixFrameHider: function () {
			Element.hide(this.IEFixFrame);
		},
		/**
		  *	Fonction permettant de cloner les position et les dimensions d'un element a un autre ( modification de celle de Prototype avec l'ajout de l'option 'toBorder' )
		  */
		clone: function(source, target) {
		    var options = Object.extend({
		      setLeft:    true,
		      setTop:     true,
		      setWidth:   true,
		      setHeight:  true,
			  toBorder:	  false,
		      offsetTop:  0,
		      offsetLeft: 0
		    }, arguments[2] || {})

		    // find page position of source
		    source = $(source);
		    var p = Position.page(source);

		    // find coordinate system to use
		    target = $(target);
		    var delta = [0, 0];
		    var parent = null;
		    // delta [0,0] will do fine with position: fixed elements,
		    // position:absolute needs offsetParent deltas
		    if (Element.getStyle(target,'position') == 'absolute') {
		      parent = Position.offsetParent(target);
		      delta = Position.page(parent);
		    }

		    // correct by body offsets (fixes Safari)
		    if (parent == document.body) {
		      delta[0] -= document.body.offsetLeft;
		      delta[1] -= document.body.offsetTop;
		    }
		    
			// Set the cumulative border dimensions of the target source
			var cumulativeBorder = {width: 0, height: 0}
			if (options.toBorder && !navigator.userAgent.match(/Netscape/)) {
				cumulativeBorder.width = target.offsetWidth - target.clientWidth;
				cumulativeBorder.height = target.offsetHeight - target.clientHeight;
			}
			//alert(delta.toString()+'  //  '+p);
			// set position
		    if(options.setLeft)   target.style.left  = (p[0] - delta[0] + options.offsetLeft) + 'px';
		    if(options.setTop)    target.style.top   = (p[1] - delta[1] + options.offsetTop) + 'px';
			if(options.setWidth)  target.style.width = source.offsetWidth - cumulativeBorder.width + 'px';
			if(options.setHeight) target.style.height = source.offsetHeight - cumulativeBorder.height + 'px';
		},
		/**
		  *	Fonction qui redefinit celle de la librairie Effects en y ajoutant la possibilite de gerer la duree de l'effet
		  */
		squishEffect: function(element) {
			return new Effect.Scale(element, window.opera ? 1 : 0, Object.extend({ 
				restoreAfterFinish: true,
				beforeSetup: function(effect) {
		        effect.element.makeClipping(effect.element); },  
				afterFinishInternal: function(effect) {
		        effect.element.hide(effect.element); 
		        effect.element.undoClipping(effect.element); }
			},
			arguments[1] || {}));
		},
		/**
		  *	Fonction permettant d'effectuer la recherche lors du fonctionnement en mode Local
		  */
		localStringFinder: 	function(entryString) {
			var results	= [];
			
			for (var i=0;i<this.localArray.length;i++) { 
				var strItem = this.localArray[i];
				var matchPos = !this.LocalModePackage.respectCase ?
										strItem.toLowerCase().indexOf(entryString.toLowerCase()) 
									: 
										strItem.indexOf(entryString);

				if (matchPos != -1) {
					if (matchPos == 0 && entryString.length < strItem.length) { 
						results.push(
							"<li style=\"width:100%\"><b>"+
							strItem.substr(0,entryString.length)
							+"</b>"+
							strItem.substr(entryString.length)
							+"</li>"
						);
					} 
					else if ((
							entryString.length >= this.LocalModePackage.nbrMinPartialChars && 
							!this.LocalModePackage.searchOnlyAtBegin && 
							matchPos > 0 ) || (
							matchPos == 0 && 
							entryString.length == strItem.length )) {
						results.push(
							"<li style=\"width:100%\">"+
							strItem.substr(0,matchPos)
							+"<b>"+
							strItem.substr(matchPos,entryString.length)
							+"</b>"+
							strItem.substr(matchPos+entryString.length)
							+"</li>"
						);
					}
				}
				
				if (results.length == this.globalOptions.nbrMaxItem) break;
			}
			return "<ul>" + results.join('') + "</ul>";
		}
	}
};

//
//	Librairie by The Rubik's Man
//		  2005-2006
//